@@ -8,6 +8,7 @@ from transformers.tokenization_utils_base import PreTrainedTokenizerBase
 from transformers.tokenization_utils_fast import PreTrainedTokenizerFast
 
 from ..base import SingleBaseMapper, TransformElementType
+from ..utils.shape_utils import flatten_with_indices, reconstruct_from_indices
 from .tokenize import GetTokenizerOutputFieldsAndNamesMixIn
 
 __all__ = [
@@ -15,6 +16,7 @@ __all__ = [
     "FillEncodedPromptMapper",
     "FillTextPromptMapper",
     "TruncateMultipleFieldsMapper",
+    "TruncateMultipleNestedFieldsMapper",
 ]
 
 
@@ -291,6 +293,31 @@ class TruncateMultipleFieldsMapper(SingleBaseMapper):
         return output
 
 
+class TruncateMultipleNestedFieldsMapper(TruncateMultipleFieldsMapper):
+    """Like TruncateMultipleFieldsMapper, but works on nested fields."""
+
+    def transform(self, data: TransformElementType) -> TransformElementType:
+        # gather fields to truncate in flatted_data, keep track of
+        # the indices of the fields in flatted_index
+        flatted_index: dict = {}
+        flatted_data: dict = {}
+
+        for k in self.input_fields:
+            flatted_data[k], flatted_index[k] = flatten_with_indices(data[k])
+
+        flatted_output = super().transform(flatted_data)
+
+        output = {
+            k: (
+                reconstruct_from_indices(flatted_output[k], flatted_index[k])
+                if k in flatted_output
+                else data[k]
+            )
+            for k in data
+        }
+        return output
+
+
 @dataclass
 class PromptSegment:
     """Class to represent a segment of a prompt. Not meant to be used
